1
0
mirror of https://git.FreeBSD.org/ports.git synced 2024-12-22 04:17:44 +00:00
freebsd-ports/news/nn/files/patch-global.c
2016-05-22 16:35:29 +00:00

18 lines
348 B
C

--- global.c.orig 2005-04-19 22:26:50 UTC
+++ global.c
@@ -1307,12 +1307,12 @@ fgetstr(FILE * f)
}
/*
* getline - gets a line from stdin
* returns the length of the line
*/
int
-getline(char *line, int max)
+get_line(char *line, int max)
{
if (fgets(line, max, stdin) == NULL)
return 0;
@@ -1307,12 +1307,12 @@ fgetstr(FILE * f)
}
/*
- * getline - gets a line from stdin
+ * get_line - gets a line from stdin
* returns the length of the line
*/